unit FindWordUnit;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, FileUtil, Forms, Controls, Graphics, Dialogs, StdCtrls,
  ExtCtrls;

type

  { TFindWordForm }

  TFindWordForm = class(TForm)
    Button_FindNext: TButton;
    Button_Cancel: TButton;
    CheckBox_CaseSensitive: TCheckBox;
    CheckBox_WholeFile: TCheckBox;
    LabeledEdit_Keyword: TLabeledEdit;
    RadioGroup_Direction: TRadioGroup;
    procedure Button_CancelClick(Sender: TObject);
    procedure Button_FindNextClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormHide(Sender: TObject);
    procedure FormKeyDown(Sender: TObject; var Key: Word; Shift: TShiftState);
    procedure FormShow(Sender: TObject);
    procedure LabeledEdit_KeywordChange(Sender: TObject);
  private
    function GetCaseSensitive: Boolean;
    function GetKeyword: string;
    function GetSearchForward: Boolean;
    function GetWholeFile: Boolean;
    procedure SetCaseSensitive(AValue: Boolean);
    procedure SetKeyword(AValue: string);
    procedure SetSearchForward(AValue: Boolean);
    procedure SetWholeFile(AValue: Boolean);
    procedure Update_ButtonState();
  public
    property Keyword: string read GetKeyword write SetKeyword;
    property CaseSensitive: Boolean read GetCaseSensitive write SetCaseSensitive;
    property WholeFile: Boolean read GetWholeFile write SetWholeFile;
    property SearchForward: Boolean read GetSearchForward write SetSearchForward;
  end;

var
  FindWordForm: TFindWordForm;

implementation

{$R *.lfm}

uses Unit1, Windows;

{ TFindWordForm }

procedure TFindWordForm.FormCreate(Sender: TObject);
begin
  //ComboBox_Keyword.Clear;
  LabeledEdit_Keyword.Clear;
  RadioGroup_Direction.ItemIndex := 1;
  CheckBox_WholeFile.Checked := TRUE;
  Update_ButtonState();
end;

procedure TFindWordForm.FormHide(Sender: TObject);
begin
  if Position = poScreenCenter then
    Position := poDefault;
end;

procedure TFindWordForm.FormKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
begin
  if Key = VK_ESCAPE then
    Self.Hide;
end;

procedure TFindWordForm.FormShow(Sender: TObject);
begin
  LabeledEdit_Keyword.SetFocus;
end;

procedure TFindWordForm.LabeledEdit_KeywordChange(Sender: TObject);
begin
  Update_ButtonState();
end;

function TFindWordForm.GetCaseSensitive: Boolean;
begin
  Result := CheckBox_CaseSensitive.Checked;
end;

function TFindWordForm.GetSearchForward: Boolean;
begin
  Result := RadioGroup_Direction.ItemIndex = 1;
end;

procedure TFindWordForm.Button_FindNextClick(Sender: TObject);
begin
  Form1.Action_EditFindNext.Execute;
end;

procedure TFindWordForm.Button_CancelClick(Sender: TObject);
begin
  Close;
end;

function TFindWordForm.GetKeyword: string;
begin
  Result := LabeledEdit_Keyword.Text;
end;

function TFindWordForm.GetWholeFile: Boolean;
begin
  Result := CheckBox_WholeFile.Checked;
end;

procedure TFindWordForm.SetCaseSensitive(AValue: Boolean);
begin
  CheckBox_CaseSensitive.Checked := AValue;
end;

procedure TFindWordForm.SetSearchForward(AValue: Boolean);
begin
  if AValue then
    RadioGroup_Direction.ItemIndex := 1
  else
    RadioGroup_Direction.ItemIndex := 0;
end;

procedure TFindWordForm.SetKeyword(AValue: string);
begin
  LabeledEdit_Keyword.Text := AValue;
end;

procedure TFindWordForm.SetWholeFile(AValue: Boolean);
begin
  CheckBox_WholeFile.Checked := AValue;
end;

procedure TFindWordForm.Update_ButtonState();
begin
  Button_FindNext.Enabled := Trim(LabeledEdit_Keyword.Text) <> '';
end;

end.

